# local RH-friendly definition of %%mkrel, so we can assume it works and drop
# other release hacking macros
%{?!mkrel: %define mkrel(c:) %{-c: 0.%{-c*}.}%{1}%{?distsuffix:.%distsuffix}%{?distversion}}
%{?!makeinstall_std: %define makeinstall_std() make DESTDIR=%{?buildroot:%{buildroot}} install}


%define compat_perl_vendorlib %(perl -MConfig -e 'print "%{?perl_vendorlib:1}" ? "%{perl_vendorlib}" : "$Config{installvendorlib}"')
%global allow_gurpmi %(perl -e 'print "%_vendor" =~ /\\bmag/i ? 1 : 0')
%define req_webfetch %(perl -e 'print "%_vendor" =~ /\\bmag/i ? "webfetch" : "curl wget"')

%global __requires_exclude perl\\(standalone\\)

Name:		urpmi
Version:	8.131
Release:	%mkrel 1
Group:		System/Packaging
License:	GPLv2+
Source0:	https://gitweb.mageia.org/software/rpm/urpmi/snapshot/%{name}-v%{version}.tar.xz
# NO PATCH ALLOWED, USE GIT INSTEAD
# (tmb) first step of handling renamed kernels...
#       could be better to detect and trigger on: Provides: installonlypkg(kernel)
#       like dnf does as inst.list is tagged config(noreplace)
Patch001:	urpmi-v8.125-add-kernels-to-inst.list.patch
Summary:	Command-line software installation tools
VCS:		https://gitweb.mageia.org/software/rpm/urpmi/
URL:		https://metacpan.org/release/urpmi
Requires:	%{req_webfetch}
Requires:	eject
Requires(post):	perl-Locale-gettext
Requires(post):	perl-URPM
Requires:	perl-URPM >= 5.13-4
# gzip is used in perl-URPM for synthesis and hdlist
Requires(post):	gzip
Requires:	genhdlist2
Requires:	meta-task
Requires:	perl-Filesys-Df
Requires:	perl-Time-ZoneInfo
Obsoletes:	urpmi-dudf
Recommends:	aria2
Recommends:	deltarpm
BuildRequires:	bzip2-devel
BuildRequires:	gettext
BuildRequires:	glibc-devel
BuildRequires:	intltool
BuildRequires:	perl
BuildRequires:  perl_checker
BuildRequires:	perl-Locale-gettext
BuildRequires:	perl-MDV-Distribconf
BuildRequires:	perl(Net::LDAP)
BuildRequires:	perl-URPM
# for make test:
#BuildRequires:  glibc-static-devel
BuildRequires:	mdv-distrib-tools
BuildRequires:	perl-File-Slurp
BuildRequires:  perl-Net-Server
BuildRequires:	perl-Test-Pod
BuildRequires:	perl(Test::Pod::Coverage)
BuildRequires:	perl-XML-LibXML
BuildRequires:	mozilla-nss
# for genhdlist in make test:
BuildRequires:  perl-Expect
BuildRequires:  rpmtools
BuildArch:	noarch
Requires:	perl-XML-LibXML >= 2.12.900-4.mga7

%description
urpmi is a console-based software installation tool. You can
use it to install software from the console in the same way as you use the
graphical Install Software tool (rpmdrake) to install software from the
desktop. urpmi will follow package dependencies -- in other words, it will
install all the other software required by the software you ask it to
install -- and it's capable of obtaining packages from a variety of media,
including the installation CD-ROMs and DVDs, your local hard disk,
and remote sources such as web or FTP sites.

%if %{allow_gurpmi}
%package -n gurpmi
Summary:	User mode rpm GUI install
Group:		System/Packaging
Requires:	urpmi >= %{version}-%{release}
Requires:	polkit
Requires(post): desktop-file-utils
Requires(postun): desktop-file-utils

%description -n gurpmi
gurpmi is a graphical front-end to urpmi.
%endif

%package -n urpmi-parallel-ka-run
Summary:	Parallel extensions to urpmi using ka-run
Requires:	urpmi >= %{version}-%{release}
Requires:	parallel-tools
Group:		System/Packaging

%description -n urpmi-parallel-ka-run
urpmi-parallel-ka-run is an extension module to urpmi for handling
distributed installation using ka-run or Taktuk tools.

%package -n urpmi-parallel-ssh
Summary:	Parallel extensions to urpmi using ssh and scp
Requires:	urpmi >= %{version}-%{release} openssh-clients
Group:		System/Packaging

%description -n urpmi-parallel-ssh
urpmi-parallel-ssh is an extension module to urpmi for handling
distributed installation using ssh and scp tools.

%package -n urpmi-ldap
Summary:	Extension to urpmi to specify media configuration via LDAP
Requires:	urpmi >= %{version}-%{release}
Requires:	openldap-clients
Group:		System/Packaging

%description -n urpmi-ldap
urpmi-ldap is an extension module to urpmi to allow to specify
urpmi configuration (notably media) in an LDAP directory.

%prep
%autosetup -p1 -n %name-v%version

%build
%{__perl} Makefile.PL INSTALLDIRS=vendor \
%if %{allow_gurpmi}
    --install-gui \
%endif
    --install-polkit \
    --install-po
%{__make}

%check
%{__make} test

%install
%make_install

# bash completion
install -d -m 755 %{buildroot}%{_sysconfdir}/bash_completion.d
install -m 644 %{name}.bash-completion %{buildroot}%{_sysconfdir}/bash_completion.d/%{name}

# rpm-find-leaves is invoked by this name in rpmdrake
ln -sf rpm-find-leaves %{buildroot}%{_bindir}/urpmi_rpm-find-leaves

# (cg) provide a urpmi.update in the path because users like to use it without
# mgaapplet installed (me included).
# If bin and sbin ever merge, real files will likely be favoured over symlinks
# and this should still operate properly (albeit with a bit of an upgrade glitch)
ln -sf %{_libexecdir}/urpmi.update %{buildroot}%{_sbindir}/urpmi.update

# Don't install READMEs twice
rm -f %{buildroot}%{compat_perl_vendorlib}/urpm/README*

# Desktop entry (only used to register new MIME type handler, so no icon etc.)
%if %{allow_gurpmi}
mkdir -p %buildroot%_datadir/applications
cp -a gurpmi.desktop %buildroot%_datadir/applications/gurpmi.desktop

mkdir -p %buildroot%_datadir/mime/packages
cat > %buildroot%_datadir/mime/packages/gurpmi.xml << EOF
<?xml version="1.0"?>
<mime-info xmlns="https://www.freedesktop.org/standards/shared-mime-info">
  <mime-type type="application/x-urpmi">
    <comment>urpmi file</comment>
    <glob pattern="*.urpmi"/>
  </mime-type>
</mime-info>
EOF
%endif

%find_lang %{name}

%preun
if [ "$1" = "0" ]; then
  cd /var/lib/urpmi
  rm -f compss provides depslist* descriptions.* *.cache hdlist.* synthesis.hdlist.* list.*
  cd /var/cache/urpmi
  rm -rf partial/* headers/* rpms/*
fi
exit 0

%files -f %{name}.lang
%dir /etc/urpmi
%dir /var/lib/urpmi
%dir /var/cache/urpmi
%dir /var/cache/urpmi/partial
%dir /var/cache/urpmi/headers
%dir /var/cache/urpmi/rpms
%config(noreplace) /etc/urpmi/skip.list
%config(noreplace) /etc/urpmi/inst.list
%{_sysconfdir}/bash_completion.d/%{name}
%{_bindir}/urpmi_rpm-find-leaves
%{_bindir}/rpm-find-leaves
%{_bindir}/urpmf
%{_bindir}/urpmq
%{_sbindir}/urpmi
%{_sbindir}/rurpmi
%{_sbindir}/rurpme
%{_sbindir}/urpme
%{_sbindir}/urpmi.addmedia
%{_sbindir}/urpmi.removemedia
%{_sbindir}/urpmi.update
%{_libexecdir}/urpmi.update
%{_mandir}/man3/*urpm*
%{_mandir}/man5/urpm*
%{_mandir}/man5/proxy*
%{_mandir}/man8/rurpm*
%{_mandir}/man8/urpme*
%{_mandir}/man8/urpmf*
%{_mandir}/man8/urpmq*
%{_mandir}/man8/urpmi.8*
%{_mandir}/man8/urpmi.addmedia*
%{_mandir}/man8/urpmi.removemedia*
%{_mandir}/man8/urpmi.update*
%{_mandir}/man8/urpmihowto*
%dir %{compat_perl_vendorlib}/urpm
%{compat_perl_vendorlib}/urpm.pm
%{compat_perl_vendorlib}/urpmi.pm
%{compat_perl_vendorlib}/urpm/args.pm
%{compat_perl_vendorlib}/urpm/bug_report.pm
%{compat_perl_vendorlib}/urpm/cfg.pm
%{compat_perl_vendorlib}/urpm/cdrom.pm
%{compat_perl_vendorlib}/urpm/download.pm
%{compat_perl_vendorlib}/urpm/get_pkgs.pm
%{compat_perl_vendorlib}/urpm/install.pm
%{compat_perl_vendorlib}/urpm/lock.pm
%{compat_perl_vendorlib}/urpm/main_loop.pm
%{compat_perl_vendorlib}/urpm/md5sum.pm
%{compat_perl_vendorlib}/urpm/media.pm
%{compat_perl_vendorlib}/urpm/mirrors.pm
%{compat_perl_vendorlib}/urpm/msg.pm
%{compat_perl_vendorlib}/urpm/orphans.pm
%{compat_perl_vendorlib}/urpm/parallel.pm
%{compat_perl_vendorlib}/urpm/prompt.pm
%{compat_perl_vendorlib}/urpm/removable.pm
%{compat_perl_vendorlib}/urpm/select.pm
%{compat_perl_vendorlib}/urpm/signature.pm
%{compat_perl_vendorlib}/urpm/sys.pm
%{compat_perl_vendorlib}/urpm/util.pm
%{compat_perl_vendorlib}/urpm/xml_info.pm
%{compat_perl_vendorlib}/urpm/xml_info_pkg.pm
%doc Changes README.zeroconf urpmi-repository-http.service

%if %{allow_gurpmi}
%files -n gurpmi
%{_bindir}/gurpmi
%{_bindir}/gurpmi2
%{_libexecdir}/gurpmi2
%{_datadir}/polkit-1/actions/org.mageia.gurpmi2.policy
%{_datadir}/applications/gurpmi.desktop
%{_datadir}/mime/packages/gurpmi.xml
%{compat_perl_vendorlib}/gurpmi.pm
%{compat_perl_vendorlib}/gurpm/RPMProgressDialog.pm
%endif

%files -n urpmi-parallel-ka-run
%doc urpm/README.ka-run
%dir %{compat_perl_vendorlib}/urpm
%{compat_perl_vendorlib}/urpm/parallel_ka_run.pm

%files -n urpmi-parallel-ssh
%doc urpm/README.ssh
%dir %{compat_perl_vendorlib}/urpm
%{compat_perl_vendorlib}/urpm/parallel_ssh.pm

%files -n urpmi-ldap
%doc urpmi.schema
%{compat_perl_vendorlib}/urpm/ldap.pm


%changelog
* Thu Apr 13 2023 tv <tv> 8.131-1.mga9
+ Revision: 1952885
- urpmi:
  o Fix --auto-orphans vs new kernel naming
    (having multuple "kernel" pkgs with different versions)

* Sat Jan 28 2023 martinw <martinw> 8.130-1.mga9
+ Revision: 1936605
- library:
  o force timestamping=off when using wget to avoid conflict with --force-clobber

* Sat Jan 21 2023 martinw <martinw> 8.129-1.mga9
+ Revision: 1934686
- library:
  o prefer wget to curl as the default downloader (mga#24362)
  o fix curl options to allow it to follow HTTP redirections (mga#31339)
- urpmq:
  o --requires/suggests: do not warn about 14y+ old behavior change (mga#26448)

* Sat Nov 05 2022 martinw <martinw> 8.128-1.mga9
+ Revision: 1903890
- library:
  o fix download with curl 7.86+ when the URL has a query part (mga#31047)
- gurpmi2:
  o fix Cancel button getting lost after first batch of downloads is done.
- translation updates

* Tue Mar 29 2022 umeabot <umeabot> 8.127-2.mga9
+ Revision: 1832547
- Mageia 9 Mass Rebuild
+ tv <tv>
- BR mozilla-nss instead of %%{_lib}nss3 so that SRPM is arch agnostic

* Sun Oct 31 2021 tv <tv> 8.127-1.mga9
+ Revision: 1753411
- Convert from bdb backend to sqlite also when not chrooted
  (live upgrades, mga#29364)
- Prefer encrypted protocols when selecting a mirror when using a mirrorlist
- cpan_testers:
  o skip rpm-v3 tests on known broken versions of rpm

* Sat Jun 05 2021 tv <tv> 8.126-1.mga9
+ Revision: 1729795
- Convert from bdb backend to sqlite when using rpm >= 4.16

* Mon Apr 26 2021 tmb <tmb> 8.125-2.mga9
+ Revision: 1719890
- temporarily disable rpm v3 header tests (upstream rpm 4.1.16.3 regression)
- BR: glibc-devel
- add kernels and kmods to urpmi inst.list in preparation for kernel renaming

* Wed Feb 17 2021 tmb <tmb> 8.125-1.mga8
+ Revision: 1675521
- translation updates

* Tue Nov 24 2020 tv <tv> 8.124-1.mga8
+ Revision: 1648857
- gurpmi2:
  o ensure download error report fits on screen
- Make it work with no feature qw(indirect) (aka perl7)
- urpmi:
  o make logs more reproductable
- urpmi.addmedia:
  o add --ignorearch option
- small Kwalitee cleanups
- stop truncating disk names when prompting for a CD/USB key
- cpan_testers:
  o fix bundled genhdlist2 wrongly defaulting to zstd
- drop pre mga7 temp conflicts due to switching perl-5.26 to use -Duse64bitint
- drop mga3->4 conflicts

* Fri May 01 2020 tv <tv> 8.123-1.mga8
+ Revision: 1577296
- cpan_testers:
  o BSD: prevent failing due to broken deps generator
  o do not skip network tests on pre-UsrMove distros (eg: Mageia 2)
  o fix running genhlist2 with the right perl version
  o fix running testsuite with rpm-4.9
  o fix testuite if glibc-static-devel isn't installed on Mageia 2
  o needs URPM 5.28 for maximal portability

* Wed Apr 29 2020 tv <tv> 8.122-1.mga8
+ Revision: 1573235
- cpan_testers:
  o adapt to a world where gcc is no more the apex predator
    (aka works out of the box when there's clang but not gcc)
  o bundled genhdlist2 and fallback to it if CPAN failed to install rpmtools
    scripts
  o check & report where genhdlist2 is
  o check that web server has actually started
  o describe more tests to help pinpoint regressions
  o display RPM version in cpan-testers logs
  o do not fail test when libnss.so is not found in Debian 9 or FreeBSD
  o fix failing to build some rpms on FreeBSD
  o fix failing tests when serving over HTTP from within /root
  o fix test with rpm < 4.13 on CentOS7
  o make sure genhdlist2 works
  o perform some file conflict tests only on Mageia
  o try harder to find genhdlist2 in uninstalled CPAN modules
  o work without glibc-static-devel
  o workaround %%find_lang sometimes failing on FreeBSD
- library:
  o enhance the doc
  o fix rpm version check causing strange warning messages:
    "shell-init: error retrieving current directory: getcwd: cannot access parent directories: No such file or directory"
- testsuite:
  o add more extensive tests
  o describe it more
  o disable fsync/fdatasync while running tests
  o make it more robust
  o make sure simple-httpd is really killed once tests are completed
  o retry if curl failed with timeout

* Thu Apr 09 2020 tv <tv> 8.121-1.mga8
+ Revision: 1565662
- urpmi:
  o add support for --reinstall
- urpmq:
  o display epoch when using -i (mga#25735)
- library:
  o add dummy package for CPAN testers & proper indexation (RT#127881)
- cpan_testers:
  o actually needs perl >= 5.10 for //= operator
  o fix a test with rpm < 4.13.0
  o fix building rpms on FreeBSD
  o fix failing scriptlets test with rpm < 4.13.0
  o fix looking for non existing libnss.so on FreeBSD
  o fix testsuite errors on CentOs (NVR vs NVRA)
  o include /usr/local/bin in PATH
  o require a newer enough Test::More & rpmtools
  o skip mirrorlist tests on !Mageia
  o skip tests if we have no supported downloader
  o skip weak deps test on CentOS 7 (unsupported)
  o testsuite needs rpmtools
  o workaround disabled nobody account (eg on CentOS7)
  o workaround 'nogroup' not existing on CentOS

* Mon Feb 17 2020 tv <tv> 8.120-2.mga8
+ Revision: 1536896
- explicitely BR mdv-distrib-tools
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild

* Mon Oct 21 2019 martinw <martinw> 8.120-1.mga8
+ Revision: 1455047
- fix test for whether any 32-bit packages are installed

* Sat Oct 19 2019 martinw <martinw> 8.119-1.mga8
+ Revision: 1454622
- when adding distrib media, enable 32-bit media if needed (mga#24438)
- translations updates
+ tmb <tmb>
- rebuild for perl 5.30

* Sat Jun 22 2019 martinw <martinw> 8.118-1.mga7
+ Revision: 1400483
- ensure downloaded files are world-readable (mga#24636)

* Sat Jun 22 2019 martinw <martinw> 8.117-1.mga7
+ Revision: 1400470
- ensure urpmi config and cache files are world-readable (mga#24636)

* Mon May 27 2019 martinw <martinw> 8.116-1.mga7
+ Revision: 1399255
- don't enable 32-bit media by default on 64-bit systems (mga#24376)
  o except on systems with 32-bit EFI, where we need the Core 32bit
    media for the bootloader

* Wed May 01 2019 tv <tv> 8.115-1.mga7
+ Revision: 1395969
- library:
  o fix _rpm_version() when rpm is translated
  o use proper versionning (RT#127142)
- testsuite:
  o make it work with rpm < 4.14.2 again
- cpan_testers:
  o add missing spec file
  o make it work with perl < 5.22.0
  o skip network tests if we don't have a downloader
  o update deps
- translations updates

* Fri Sep 21 2018 umeabot <umeabot> 8.114-2.mga7
+ Revision: 1291985
- Mageia 7 Mass Rebuild

* Mon Sep 17 2018 tv <tv> 8.114-1.mga7
+ Revision: 1259343
- enhanced doc
- fix testsuite with rpm-4.14.2

* Fri Sep 14 2018 tv <tv> 8.113-1.mga7
+ Revision: 1258960
- adapt testsuite to rpm-4.14.0~rc1
- add support for verify callback when installing (mga#23531)

* Thu Aug 09 2018 tv <tv> 8.112-2.mga7
+ Revision: 1250563
- rebuild for perl-5.28

* Thu Jun 14 2018 tv <tv> 8.112-1.mga7
+ Revision: 1236884
- fix bogus translations that breaks build
- cpan testers:
  o add metadata
  o list needed deps
- urpmi_rpm-find-leaves
  o fix running with perl-5.26 (mga#23172)
- MDV::Packdrakeng is no more needed since 2008...

* Sun Oct 01 2017 tv <tv> 8.111-2.mga7
+ Revision: 1162256
- BR nss3 lib for testsuite
- set ExclusiveArch in order to go past BS
- gurpmi:
  o update perl-Pango first too (mga#21425)
- urpmi:
  o update perl-base first too
  o use XML::LibXML::Parser's 'huge' option
- drop now useless workaround
- adjust requires to make sure we update the perl stack with the proper modules
  after the ABI breakage
- workaround a testsuite regression regarding debuginfo not anymore disablable
  with undefying %%debug_package

* Sun Jul 16 2017 tmb <tmb> 8.110-3.mga7
+ Revision: 1123567
- bump rel past mga6 updates

* Thu Jul 13 2017 akien <akien> 8.110-2.mga6
+ Revision: 1109729
- Version 8.110, works around gurpmi2 segfault (mga#21167)

* Thu Jul 06 2017 tmb <tmb> 8.110-1.mga6
+ Revision: 1109139
- update translations

* Mon Jun 05 2017 akien <akien> 8.109-1.mga6
+ Revision: 1106948
- Version 8.109, translation updates

* Tue May 09 2017 tv <tv> 8.108-1.mga6
+ Revision: 1099887
- increase transaction size from 8 to 50 (mga#18426)
  (patch has been merged)

* Wed Apr 26 2017 akien <akien> 8.107-1.mga6
+ Revision: 1097688
- Version 8.107
  o make sure that urpmi.cfg is world-readable (mga#9386)
  o ensure gurpmi ProgressDialog centering (mga#19196)
  o update Mageia copyright statements
  o translation updates

* Wed Feb 22 2017 tv <tv> 8.106-2.mga6
+ Revision: 1087355
- increase transaction size from 8 to 50 (mga#18426)

* Wed Feb 22 2017 tv <tv> 8.106-1.1.mga6
+ Revision: 1087348
+ rebuild (emptylog)

* Tue Dec 06 2016 tv <tv> 8.106-1.mga6
+ Revision: 1072725
- skip kernel-firmware-nonfree too when considering real kernels
  Thus preventing kernel-firmware-nonfree being falsely detected as an orphan
  package (mga#12361)

* Thu Oct 20 2016 tv <tv> 8.105-1.mga6
+ Revision: 1062799
- adapt testsuite to rpm-4.13.0~rc2

* Sat Oct 15 2016 tv <tv> 8.104-1.mga6
+ Revision: 1060834
- fix more Getopt::Long breakages (drop the "gnu_compat" option)
- add a VCS tag

* Mon Jul 11 2016 tv <tv> 8.103-1.mga6
+ Revision: 1041143
- remove patch and add a notice about no patches vs git
- fix reporting progress with newer aria2 (mga#16500)
- fix Getopt::Long 4.60+ breakages (mga#17923)
- s/suggests/recommends/ in bash completion
+ ghibo <ghibo>
- Added Patch0 to fix bug #16500, so that aria2 download progress works again.

* Sun Jun 19 2016 pterjan <pterjan> 8.102-2.mga6
+ Revision: 1036651
- Rebuild for perl 5.22.2

* Thu Apr 14 2016 tv <tv> 8.102-1.mga6
+ Revision: 1001430
- add --deploops & --debug-librpm to bash completion
- unset LD_PRELOAD in chroot (eg: for eatmydata)
- use new "elem" callback
  (need URPM >= 5.07)

* Sat Jan 02 2016 tv <tv> 8.101-1.mga6
+ Revision: 918420
- switch from %%makeinstall_std to %%make_install
- prefer http mirrors when using a mirrorlist, this avoids selecting an rsync
  mirror which prevents aria2 from being used

* Fri Oct 09 2015 tv <tv> 8.10-1.mga6
+ Revision: 888399
- patch 0: fix build
- fix urpm::bug_report (mga#16925)

* Fri Sep 04 2015 tv <tv> 8.09-1.mga6
+ Revision: 872857
- fix urpm::parallel

* Fri Sep 04 2015 tv <tv> 8.08-1.mga6
+ Revision: 872789
- fix installing /sbin/*
  (regression with perl-5.22's ExtUtils-MakeMaker now wrapping $(...) )
- fix perl_checker checking
- aria2 downloading:
  o fix using a proxy without an auth user (mga#11265)
- library:
  o fix unmarking packages as potential orphans when downgrading (mga#16149)
  o fix Term::ReadKey warnings when output is redirected
- testsuite:
  o misc enhancements & cleanups
  o fix tests for ignored faillure for %%pre{,un}, %%pretrans
    (was ignored since rpm-4.9.0)
  o test that %%pretrans do fail installtion (needs rpm-4.13)

* Mon May 18 2015 tv <tv> 8.06-1.mga5
+ Revision: 822316
- translation update

* Wed Mar 18 2015 tv <tv> 8.05-1.mga5
+ Revision: 818767
- gurpmi:
  o install perl-Glib-Object-Introspection as priority upgrades prior to restart

* Thu Feb 26 2015 tv <tv> 8.04-1.mga5
+ Revision: 817033
- always display the right package name on errors (mga#15032)

* Thu Jan 01 2015 tv <tv> 8.03-1.mga5
+ Revision: 808014
- enhanced doc

* Tue Nov 25 2014 tv <tv> 8.02-1.mga5
+ Revision: 798882
- gurpmi:
  o fix --auto not working anymore (mga#14565)
    (regression introduced in 7.32)
+ shlomif <shlomif>
- Add the version control URL

* Wed Oct 15 2014 umeabot <umeabot> 8.01-2.mga5
+ Revision: 745502
- Second Mageia 5 Mass Rebuild

* Thu Oct 09 2014 tv <tv> 8.01-1.mga5
+ Revision: 737710
- revert "bump split-length from 8 to 50"

* Tue Sep 16 2014 umeabot <umeabot> 8.00-5.mga5
+ Revision: 690081
- Mageia 5 Mass Rebuild
+ tv <tv>
- s/uggests:/Recommends:/

* Sun Sep 14 2014 tv <tv> 8.00-4.mga5
+ Revision: 675469
- fix requires exception

* Sat Sep 13 2014 tv <tv> 8.00-2.mga5
+ Revision: 675169
- add exception for standalone module

* Sat Sep 13 2014 tv <tv> 8.00-1.mga5
+ Revision: 675073
- rpm-4.12 support:
  o adapt to URPM-5.00
  o rename 'no_suggests' parameter as 'no_recommends'
  o rename '--allow-suggests' option as '--allow-recommends'
  o rename '--no-suggests' option as '--no-recommends'
  o rename '--suggests' option as '--recommends'

* Fri Sep 05 2014 tv <tv> 7.32-1.mga5
+ Revision: 672209
- add some missing methods, allows to do urpmf --qf '%%sourcerpm:%%requires'
- bump split-length from 8 to 50
  improves installing gnome in a chroot from 14m to 11m
- update bash completion
- gurpmi:
  o fix crashing when choosing to save file
  o fix segfaulting when managing exceptions
  o report crashes through drakbug
- fix some warnings with perl 5.20

* Fri Jan 24 2014 tv <tv> 7.31-1.mga4
+ Revision: 567687
- do not exec pkexec but run it so it has a parent process to fix double fork
  issues mga#11184 mga#12364
- gurpmi:
  o fix garbaged UTF-8 in file name arguments (mga#12407)

* Thu Dec 05 2013 tv <tv> 7.30-1.mga4
+ Revision: 555323
- convert from gtk2 to gtk3

* Tue Dec 03 2013 tv <tv> 7.29-1.mga4
+ Revision: 554769
- use /proc/self/mountinfo for ro filesystem checks mga#11319
- polkit: only use pkexec when not already root

* Tue Nov 05 2013 tv <tv> 7.28-1.mga4
+ Revision: 549635
- library:
  o fix parsing download progress with rsync >= 3.10
- urpmi:
  o add support for --deploops option (needs URPM-4.29+)

* Mon Oct 28 2013 colin <colin> 7.27.5-3.mga4
+ Revision: 547620
- Provide sbin version of urpmi.update as users miss it.

* Tue Oct 22 2013 umeabot <umeabot> 7.27.5-2.mga4
+ Revision: 541579
- Mageia 4 Mass Rebuild

* Sun Oct 13 2013 colin <colin> 7.27.5-1.mga4
+ Revision: 496212
- New version: 7.27.5

* Fri Oct 04 2013 tv <tv> 7.27.4-1.mga4
+ Revision: 491337
- library:
  o adapt to perl-5.18
  o prevent disabling removing orphan if we failed to detect running kernel
    version

* Thu May 30 2013 tv <tv> 7.27.3-1.mga4
+ Revision: 433024
- library:
  o revert fix for mga#10254 in previous release
    (the bug was in media.cfg, mga#10335)

* Wed May 29 2013 tv <tv> 7.27.2-2.mga4
+ Revision: 429879
- rebuild for new perl

* Fri May 24 2013 tv <tv> 7.27.2-1.mga4
+ Revision: 426850
- library:
  o ensure priority updates are installed in a single transaction
  o fix wrongly enabling backports/testing for tainted/nonfree when
    such packages are already installed (mga#10254)

* Fri May 17 2013 tv <tv> 7.27.1-1.mga3
+ Revision: 413472
- library:
  o really auto enable tainted media if needed when adding distrib media

* Fri May 17 2013 tv <tv> 7.27-1.mga3
+ Revision: 413451
- gurpmi2:
  o like urpmi/rpmdrake/drakx, display all errors at once at end
    instead of forcing users to click in order to continue
    transactions (mga#6086)
  o do not popup errors at end in auto mode
- library (mga#8368, #8379 & #9758):
  o enable to see if nonfree/tainted packages are installed
  o auto enable nonfree/tainted media if needed when adding distrib media

* Thu May 02 2013 tv <tv> 7.26-1.mga3
+ Revision: 411941
- gurpmi2:
  o sort package list
- library:
  o fix displaying removed package name in gurpmi/rpmdrake (mga#9545)

* Sun Apr 21 2013 tv <tv> 7.25-1.mga3
+ Revision: 410658
- library:
  o enable rpmdrake to not use modal dialogs (mga#9646)
  o fix leaving read locks on rpmdb (mga#9248)

* Thu Apr 18 2013 tv <tv> 7.24-1.mga3
+ Revision: 410437
- library:
  o display exceptions that happened while downloading (mga#9529)
- urpmi:
  o fix package count when a package has a %%pretrans scriptlet

* Sun Mar 24 2013 tv <tv> 7.23-1.mga3
+ Revision: 404820
- library:
  o enable to report packages signature checking in global progress bar dialog
- gurpmi2:
  o improved layout:
    * only the package list needs a scrolling bar
    * always display space information
  o display the addionnal space that will be used and the amount of downloaded
    packages instead of the total size of the packages (like urpmi)
  o fix return value (mga#9519)
  o report packages signature checking in global progress bar dialog

* Thu Mar 21 2013 tv <tv> 7.22-1.mga3
+ Revision: 404406
- library:
  o account for packages to erase in gurpm progress bar
  o enable to have a cancel button in global progress bar dialog
- gurpmi2:
  o enable to cancel downloads
  o fix setting download callback

* Thu Mar 21 2013 tv <tv> 7.21-1.mga3
+ Revision: 404315
- library:
  o restore main_window when globall progress bar dialog is deleted

* Tue Mar 19 2013 tv <tv> 7.20-1.mga3
+ Revision: 404092
- library:
  o drop 'callback_report_uninst' now that 'callback_uninst' enables to get
    erasure progress
  o enable rpmdrake/gurpm/drakx to pass their own callbacks for erasure
    progress & errors
  o enhanced doc
  o revert 'fixing (g)urpmi --auto-select --update defaulting to all media when
    there're no update media (#1024)' as it break looking for deps in other media
    with --update (mga#2317)
- gurpmi:
  o split global progress bar widget for rpmdrake (mga#778)
  o show removed packages in progress too
  o support exceptions in callback in main wrapper too
  o support other distros which do not handle exceptions in gtk+ callbacks
  o use new exception management
- fix URL

* Sat Feb 09 2013 tv <tv> 7.19-1.mga3
+ Revision: 397669
- add basic support for --downgrade (mga#6655, needs URPM-4.26)

* Sat Feb 09 2013 tv <tv> 7.18-1.mga3
+ Revision: 397549
- keep a separate counter for erasures

* Tue Feb 05 2013 tv <tv> 7.17-1.mga3
+ Revision: 394671
- fix counting for erasures
- restore quiet behavior for erasures when not in verbose mode

* Sun Feb 03 2013 tv <tv> 7.16-1.mga3
+ Revision: 394314
- add basic support for detecting I/O error
- display erasure progress too

* Tue Jan 22 2013 fwang <fwang> 7.15.1-3.mga3
+ Revision: 390696
- update rpm group

* Mon Jan 14 2013 umeabot <umeabot> 7.15.1-2.mga3
+ Revision: 385116
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Dec 18 2012 tv <tv> 7.15.1-1.mga3
+ Revision: 332350
- library:
  o fix retrieving rpm version with stable rpm

* Mon Dec 17 2012 tv <tv> 7.15-1.mga3
+ Revision: 332068
- library:
  o do not show empty information from README* with --justdb
  o fix retrieving rpm version with beta versions

* Thu Dec 13 2012 tv <tv> 7.14-1.mga3
+ Revision: 330476
- library:
  o associate media_cfg data to media when adding them
- fix missing BR after grousse's changes in testsuite

* Tue Dec 04 2012 tv <tv> 7.13-1.mga3
+ Revision: 326599
- library speedups when looking up packages:
  o do not attempt fuzzy matching if not requested
- urpmq:
  o do not allow substring matching with --fuzzy (mga#2953)

* Tue Dec 04 2012 tv <tv> 7.12.1-1.mga3
+ Revision: 326494
- urpmi:
  o fix missing logs

* Sun Dec 02 2012 tv <tv> 7.12-1.mga3
+ Revision: 325277
- library:
  o fix an incomplete message
  o fix --download-all (mga#8272)
    (broken by "make --use-distrib works as user" in 7.9)

* Sat Nov 17 2012 tv <tv> 7.11.1-1.mga3
+ Revision: 319168
- fix installing delta rpms

* Fri Nov 16 2012 tv <tv> 7.11-1.mga3
+ Revision: 318943
- library:
  o fix installing delta rpms (it never worked before)
  o fix computing kernel orphans when running kernel is not the latest

* Wed Oct 17 2012 tv <tv> 7.10-1.mga3
+ Revision: 307687
- do not offer to remove DKMS modules for current kernel (mga#5092)
- aria2 downloading:
  o do not use aria2 deprecated option (Sam Bailey, mga#7781)
  o reenable aria2 + metalink for downloading metadata by default (mdv)
  o tune aria2 download parameters for faster and more reliable options (mdv)
  o suppress aria2's printing of summaries to avoid it confusing urpmi parsing
    the output (mdv, mga#7776)

* Thu Oct 11 2012 tv <tv> 7.9-1.mga3
+ Revision: 304701
- adjust file list
- drop again urpmi.recover
  (no more possible since rpm 4.6 which doesn't handle --repackage)
- drop --repackage option (non working since 2009)
- gurpmi:
  o add scrollbar for long one liner messages (mga#5118)
  o wrap big messages (mga#5118)
- library:
  o enhanced doc
- urpm[fq]:
  o make --use-distrib works as user (mga#1225)

* Thu Oct 04 2012 tv <tv> 7.8.3-1.mga3
+ Revision: 302822
- fix urpmq --whatrequires regression introduced in 7.8.2 (#7706)

* Wed Sep 26 2012 tv <tv> 7.8.2-1.mga3
+ Revision: 298463
- adapt to URPM-4.15
- remove long deprecated & unused functions

* Sat Sep 08 2012 tv <tv> 7.8.1-1.mga3
+ Revision: 289960
- fix urpmq -h (mga#7390)

* Fri Sep 07 2012 tv <tv> 7.8-1.mga3
+ Revision: 289339
- add urpm::check_cache_dir() for mgaonline (mga#6083)

* Wed Sep 05 2012 tv <tv> 7.7-1.mga3
+ Revision: 288632
- use xz instead of lzma in order to read metadata

* Sat Sep 01 2012 tv <tv> 7.6-1.mga3
+ Revision: 286795
- translation updates

* Fri Aug 31 2012 tv <tv> 7.5-1.mga3
+ Revision: 286734
- fix testsuite
- library:
  o drop urpm::download::sync() (obsolete for years)
  o enhanced doc
  o internal cleanup (needs new drakx/rpmdrake)
- security:
  o downgrade missing medium key check question to a warning for virtual media
    without keys when using urpmi --use-distrib
  o downgrade missing signature check for local packages from a question to a
    warning
  o honor per medium "verify-rpm" option for missing signature check
  o media have keys, not signatures
  o prefix some messages with "SECURITY:"
  o warn about packages we don't check even if not using -v
- unrequested package list management (for orphans) (mga#7167):
  o do not wrongly tell we updated the unrequested package list when we didn't
    (eg: when not having the proper rights such as running urpmq as !root)
  o only write the unrequested package list file if the list actually changed
- urpmi.addmedia:
  o add --(no-)verify-rpm options
- urpmq: minor documentation fix (mga#7166)

* Fri Aug 24 2012 tv <tv> 7.4-1.mga3
+ Revision: 283746
- decrease total package count when some files are missing
- fix installing a package if user acks bogus signature
  (regression introduced in 7.0)
- security:
  o warn about missing signatures on packages from media without signatures
  o warn when a medium has no signature
  o warn when signature checking is disabled per medium

* Fri Aug 24 2012 pterjan <pterjan> 7.3-1.mga3
+ Revision: 283442
- Only search for README.urpmi files in doc files

* Thu Jun 28 2012 tv <tv> 7.2-1.mga3
+ Revision: 264787
- urpme: simplify traversing DB (needs URPM >= 4.10)

* Wed Jun 13 2012 tv <tv> 7.1-1.mga3
+ Revision: 260346
- adapt to URPM-4.2

* Tue Jun 12 2012 dams <dams> 7.0-2.mga3
+ Revision: 260048
- fix compilation when gurpmi is disable (by Nicolas Lécureuil)
- clean specfile

* Fri Jun 08 2012 tv <tv> 7.0-1.mga3
+ Revision: 257951
- adapt to perl-5.16.0
- adapt to rpm-4.10.0
- enhance man pages caption (inspirated by mdv)
- fix testsuite regressions
- o make 'basename' option work again for rpmdrake
- urpmi:
  o do not try to run gmessage as gtkdialogs is not packaged in Mga
  o drop support for --gui (no more used by drakx)
  o heavy refactorization
- urpmi.cfg:
  o support --download-all as an option (Pavel Shved)
- urpmf:
  o fix -m option not showing media names (mga#5916)

* Mon Apr 23 2012 tv <tv> 6.48.1-1.mga2
+ Revision: 233020
- urpmi:
  o do not print orphans message when no package is orphan (mga#4715)
- kill mdv reference in man pages (#5277)

* Mon Mar 26 2012 tv <tv> 6.48-1.mga2
+ Revision: 226924
- fix a debug message
- fix downloading twice noarch packages on x86_64 with --download-all (mga#4867)
- gurpmi:
  o install perl-{Glib,Gtk2} as priority upgrades prior to restart (mga#5066)
- updated translations
- bash completion:
  o bump available packages list speed (mga#373)
  o fix installed packages completion (mga#4937)
- urpmi:
  o align columns headers to the columns values in package list

* Mon Mar 05 2012 tv <tv> 6.46-1.mga2
+ Revision: 219257
- explicitely close the RPM DB after each transaction
- fix circular dependency that defeats perl's GC
- warn if --allow-force, --allow-nodeps, --force or --keep is in use (mga#3127)

* Mon Mar 05 2012 tmb <tmb> 6.45-3.mga2
+ Revision: 218595
- revert the removal of refcount workaround as it breaks BS (tv)

* Wed Feb 29 2012 tv <tv> 6.45-2.mga2
+ Revision: 216203
- requires instead of suggests genhdlist2 & eject (mga#4690)

* Mon Feb 27 2012 tv <tv> 6.45-1.mga2
+ Revision: 215716
- urpmi-dudf is dead
- urpmi:
  o downgrade from rpm-4.9 to 4.8 db when installing mga1 in a chroot from
    mga2+ (mga#4590)
  o fix urpmi failing silently and with exit status 0 when package
    installation fails due to either conflicts (mdv#63072) or to
    unselecting package (mdv#63940)
  o kill unused DUDF support (mga#4493)
  o return the proper error code in some cases when failing to install some
    packages
  o --test: do not display "More information on package"
  o --test: do not update /var/lib/rpm/installed-through-deps.list
- urpmi.addmedia:
  o fix $ARCH and $VERSION keyword substition in media URL
- urpmq:
  o non-zero exit code if .rpm file was not found (POK, mdv#64969)

* Tue Feb 07 2012 tv <tv> 6.44-1.mga2
+ Revision: 206172
- fix package count when using -a and when some packages exist in several
  repositories (eg: noarch packages) (mga#4322)
- translation updates

* Mon Jan 23 2012 tv <tv> 6.43.1-1.mga2
+ Revision: 200397
- do not test urpm::dudf
- kill a minor GC cycle
- Suggests instead of Requires eject & genhdlist2 (rarely used)
  (maybe eject should be pushed by installer when needed instead...)
- do not require gnupg (useless)
- do not BR urpmi-dudf

* Fri Jan 06 2012 tv <tv> 6.43-2.mga2
+ Revision: 192685
+ rebuild (emptylog)

* Fri Jan 06 2012 tv <tv> 6.43-1.mga2
+ Revision: 192680
- urpmf, urpmq:
  o fix using xml info files with quotes in medium name
- urpmi
  o do not compute orphan packages when handling priority upgrades
  o disable dudf support (we've nothing server side)
  o fix checking available space of mount point (mga#1342)
  o fix reading unrequested packages list when chrooted
  o fix already installed noarch packages are listed twice on x86_64 (mga#4038)

* Mon Dec 05 2011 tv <tv> 6.42-1.mga2
+ Revision: 176719
- urpmi.addmedia:
  o do not pick rsync medium if rsync is not installed (mga#3557)
- urpmi.update:
  o document that -a only works on enabled media (mga#3190)
+ dmorgan <dmorgan>
- Fix URL: ( mga #3278)

* Fri Oct 14 2011 tv <tv> 6.41-1.mga2
+ Revision: 155261
- add infrastructure for rpmdrake (#920)
- add infrastructure so that GUIes can offer not to ask anymore about missing
  or bad packages
- fix broken 'urpmi --no-md5sum' (pok, mga#62557)
- use rsync to download from rsync-mirrors (Alexander Barakin, mga#2518)
- drop merged patches
- BR urpmi-dudf for testsuite
- drop old urpmi trigger from 6.18-1mdv2009.1 (Oct 28 2008)
- drop mimelnk as it was only used by KDE3 (Funda Wang)
- don't suggest perl-Hal-Cdroms, will be pulled by installer when installing
  from CD
+ dmorgan <dmorgan>
- Remove unneeded rpm stuffs

* Sat May 07 2011 tv <tv> 6.40-9.mga1
+ Revision: 95834
- patch2: fix (g)urpmi --auto-select --update defaulting to all media when
  there're no update media (#1024):

* Sun May 01 2011 tmb <tmb> 6.40-8.mga1
+ Revision: 94095
- replace harcoded cauldron with product_version in mirror api url
+ misc <misc>
- remove comment about CVS
- change description to be more generic ( and also more up to date )

* Mon Mar 14 2011 misc <misc> 6.40-7.mga1
+ Revision: 71326
- hardcode the group ( as this start to be complicated to manage properly )
- do not requires specific version for building
- remove useles version on Requires, as they are on version that are present since 4 years
- remove old very specific trigger
- remove very old trigger
- do not explictely requires perl, let rpm do it itself
- do not use mandriva prefix, use a macro
- remove old Obsoletes on grpmi ( date back to mdk time )
- fix group
- remove old conflict/obsoletes ( everything is older than 2008.0 )

* Sun Feb 27 2011 dmorgan <dmorgan> 6.40-6.mga1
+ Revision: 61309
- Rebuild against new rpm

* Tue Feb 15 2011 tmb <tmb> 6.40-5.mga1
+ Revision: 51984
- remove unused Disttag and Distepoch

* Mon Feb 14 2011 tmb <tmb> 6.40-4.mga1
+ Revision: 51768
- hardcode api url for alpha1

* Mon Feb 14 2011 tmb <tmb> 6.40-3.mga1
+ Revision: 51720
- fix mirrorlist api url

* Mon Feb 14 2011 tmb <tmb> 6.40-2.mga1
+ Revision: 51714
- fix api url (P0)
- drop rpm tags

* Fri Jan 21 2011 erwan <erwan> 6.40-1.mga1
+ Revision: 30646
- Removing useless macro
- Updating regxep to match mageia
+ kharec <kharec>
- imported package urpmi

